@@ -12,6 +12,8 @@ use Config qw/%Config/;
 # The minimum allowed versions of the compilers.
 my $clangmin = 3.9;
 my $gccmin = 4.9;
+# Version regexp matches 1.1.1 etc.
+my $vre = qr!((?:[0-9]+\.)+[0-9]+)!;
 
 sub check_cc_version
 {
@@ -20,16 +22,17 @@ sub check_cc_version
 	die "I cannot find a C compiler in your \%Config";
     }
     my $version = `$cc --version`;
-    if ($version =~ /clang.*?([0-9.]+)/) {
+    if ($version =~ /clang.*?$vre/) {
 	compiler ('clang', $1, $clangmin);
 	return;
     }
-    if ($version =~ /gcc.*?([0-9.]+)/) {
+    if ($version =~ /gcc.*?$vre/) {
 	compiler ('gcc', $1, $gccmin);
 	return;
     }
     # Need to add tests for MSVC compiler here to check it is 2015 or
     # later, according to Biggers' README page.
+    warn "Your compiler, $version, may be incompatible with libdeflate";
 }
 
 sub compiler
